Documentation
¶
Overview ¶
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OperationContext ¶
type OperationResolver ¶
type OperationResolver interface {
Resolve(api dsl.ApiDescriptor, meta dsl.Meta, ctx msgresolution.AdaptorContext, descriptor dsl.OpDescriptor) []OperationContext
}
func New ¶
func New(r registry.Registry) OperationResolver