Documentation
¶
Overview ¶
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type MessageContainer ¶
type MessageContainer struct {
MessageName string
PackageName string
MessageParent *MessageContainer
MessageDefinitions []*MessageContainer
MessageFields []*MessageField
}
func (*MessageContainer) Definitions ¶
func (m *MessageContainer) Definitions() []registry.Message
func (*MessageContainer) Fields ¶
func (m *MessageContainer) Fields() []registry.Field
func (*MessageContainer) FullName ¶
func (m *MessageContainer) FullName() string
func (*MessageContainer) Name ¶
func (m *MessageContainer) Name() string
func (*MessageContainer) Package ¶
func (m *MessageContainer) Package() string
func (*MessageContainer) Parent ¶
func (m *MessageContainer) Parent() registry.Message
type MessageField ¶
type MessageField struct {
FieldType registry.FieldType
FieldName string
FieldMessageType registry.Message
FieldContext registry.Message
RepeatedField bool
}
func (*MessageField) Context ¶
func (m *MessageField) Context() registry.Message
func (*MessageField) Message ¶
func (m *MessageField) Message() registry.Message
func (*MessageField) Name ¶
func (m *MessageField) Name() string
func (*MessageField) Repeated ¶
func (m *MessageField) Repeated() bool
func (*MessageField) Type ¶
func (m *MessageField) Type() registry.FieldType
type Parser ¶
type Parser interface {
AddProtoContainer(file *descriptorpb.FileDescriptorProto) error
SaveRegistry() error
}
func LoadParser ¶
type ServiceContainer ¶
type ServiceContainer struct {
UnaryOps []*UnaryOperationContainer
PackageName string
ServiceName string
}
func (*ServiceContainer) Name ¶
func (s *ServiceContainer) Name() string
func (*ServiceContainer) Package ¶
func (s *ServiceContainer) Package() string
func (*ServiceContainer) UnaryOperations ¶
func (s *ServiceContainer) UnaryOperations() []registry.UnaryOperation
type UnaryOperationContainer ¶
type UnaryOperationContainer struct {
InputMsg registry.Message
OutputMsg registry.Message
OpName string
OpCtx *ServiceContainer
}
func (*UnaryOperationContainer) Context ¶
func (o *UnaryOperationContainer) Context() registry.Service
func (*UnaryOperationContainer) FullName ¶
func (o *UnaryOperationContainer) FullName() string
func (*UnaryOperationContainer) Input ¶
func (o *UnaryOperationContainer) Input() registry.Message
func (*UnaryOperationContainer) Name ¶
func (o *UnaryOperationContainer) Name() string
func (*UnaryOperationContainer) Output ¶
func (o *UnaryOperationContainer) Output() registry.Message