Documentation
¶
Overview ¶
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
This source file is part of the carousell/aggproto open source project
Copyright © 2021 Carousell and the project authors Licensed under Apache License v2.0
See https://github.com/carousell/aggproto/blob/master/LICENSE for license information See https://github.com/carousell/aggproto/graphs/contributors for the list of project authors
Index ¶
- type InputContext
- func (i *InputContext) AddStageDependency(stage stage.Stage)
- func (i *InputContext) GetStageDependencies() []stage.Stage
- func (i *InputContext) PrintCode(printerFactory printer.Factory) error
- func (i *InputContext) PrintCodeUsage(p printer.Printer)
- func (i *InputContext) PrintProto(factory printer.Factory)
- type InputResolver
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InputContext ¶
type InputContext struct {
// contains filtered or unexported fields
}
func (*InputContext) AddStageDependency ¶
func (i *InputContext) AddStageDependency(stage stage.Stage)
func (*InputContext) GetStageDependencies ¶
func (i *InputContext) GetStageDependencies() []stage.Stage
func (*InputContext) PrintCode ¶
func (i *InputContext) PrintCode(printerFactory printer.Factory) error
func (*InputContext) PrintCodeUsage ¶
func (i *InputContext) PrintCodeUsage(p printer.Printer)
func (*InputContext) PrintProto ¶
func (i *InputContext) PrintProto(factory printer.Factory)
type InputResolver ¶
type InputResolver interface {
Resolve(api dsl.ApiDescriptor, meta dsl.Meta, input []dsl.ArgDescriptor, opCtxs []opresolution.OperationContext, context msgresolution.AdaptorContext) (*InputContext, error)
}
func New ¶
func New(r registry.Registry) InputResolver